@@ -140,6 +140,20 @@ int main(int argc, char *argv[])
     fstring = malloc(fstringlen + 1);
     *fstring = '\0';
 
+    /* interface for American Fuzzy Lop */
+    if (AFL_MODE) {
+	FILE *fp = fdopen(0, "r");
+	char *buf = NULL;
+	size_t len = 0;
+
+	/* read one line from stdin */
+	if (getline(&buf, &len, fp) < 0)
+	    err_sys("getline");
+	fflush(fp);
+	/* and use it as command line arguments */
+	argv = merge_args(buf, argv, &argc);
+    }
+
     /* prepend options from environment */
     argv = merge_args(getenv("WHOIS_OPTIONS"), argv, &argc);
 
@@ -497,8 +511,7 @@ char *guess_server(const char *s)
     if (strchr(s, '@'))
 	return strdup("\x05");
 
-    /* no dot and no hyphen means it's a NSI NIC handle or ASN (?) */
-    if (!strpbrk(s, ".-")) {
+    if (!strpbrk(s, ".")) {
 	/* if it is a TLD or a new gTLD then ask IANA */
 	for (i = 0; tld_serv[i]; i += 2)
 	    if (strcaseeq(s, tld_serv[i]))
@@ -507,7 +520,10 @@ char *guess_server(const char *s)
 	for (i = 0; new_gtlds[i]; i++)
 	    if (strcaseeq(s, new_gtlds[i]))
 		return strdup("whois.iana.org");
+    }
 
+    /* no dot and no hyphen means it's a NSI NIC handle or ASN (?) */
+    if (!strpbrk(s, ".-")) {
 	if (strncaseeq(s, "as", 2) &&		/* it's an AS */
 		(isasciidigit(s[2]) || s[2] == ' '))
 	    return strdup(whereas(atol(s + 2)));
@@ -907,6 +923,13 @@ int openconn(const char *server, const char *port)
     struct sockaddr_in saddr;
 #endif
 
+    /*
+     * When using American Fuzzy Lop get the data from it using stdin
+     * instead of connecting to the actual whois server.
+     */
+    if (AFL_MODE)
+	return (dup(0));
+
     alarm(60);
 
 #ifdef HAVE_GETADDRINFO
